Get scores
get_scores.Rdget_scores() returns information about scores as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.
Value
A data frame where each row is a task ability score. See our Scoring and Psychometrics page to learn how to interpret scores.