Skip to contents

get_trials() returns information about each trial as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.

Usage

get_trials(data_source, version = "current")

Arguments

data_source

Name of Redivis dataset

version

Version of Redivis dataset

Value

A data frame where each row is a trial.

Examples

if (FALSE) { # \dontrun{
trials <- get_trials(dataset = "levante_data_example:d0rt", version = "current")
} # }