Get participants
get_participants.Rdget_participants() returns information about participants as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.
get_participants.Rdget_participants() returns information about participants as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.