Get raw table
get_raw_table.Rdget_raw_table() returns any table from Redivis as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.
get_raw_table.Rdget_raw_table() returns any table from Redivis as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.