Get trials
get_trials.Rdget_trials() returns information about each trial as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.
get_trials.Rdget_trials() returns information about each trial as a data frame. See the rlevante documentation for more information about how to access LEVANTE datasets and codebooks.